@@ -3,14 +3,20 @@
 -- License     :  BSD-3-Clause
 -- Maintainer  :  Oleg Grenrus <oleg.grenrus@iki.fi>
 --
--- This module re-exports all request constructrors and data definitions from
+-- This module re-exports all request constructors and data definitions from
 -- this package.
 --
--- See "GitHub.Request" module for executing 'Request', or other modules
--- of this package (e.g. "GitHub.Endpoints.Users") for already composed versions.
+-- See "GitHub.Request" module for executing 'Request', in short
+-- use @'github' request@, for example
+--
+-- @
+-- 'github' 'userInfoForR'
+--   :: 'AuthMethod' am => am -> 'Name' 'User' -> IO (Either 'Error' 'User')
+-- @
 --
 -- The missing endpoints lists show which endpoints we know are missing, there
 -- might be more.
+--
 module GitHub (
     -- * Activity
     -- | See <https://developer.github.com/v3/activity/>
@@ -56,7 +62,6 @@ module GitHub (
     -- Missing endpoints:
     --
     -- * Query a specific revision of a gist
-    -- * Create a gist
     -- * Edit a gist
     -- * List gist commits
     -- * Check if a gist is starred
@@ -64,6 +69,7 @@ module GitHub (
     -- * List gist forks
     gistsR,
     gistR,
+    createGistR,
     starGistR,
     unstarGistR,
     deleteGistR,
@@ -94,6 +100,8 @@ module GitHub (
     referenceR,
     referencesR,
     createReferenceR,
+    deleteReferenceR,
+    namespacedReferencesR,
 
     -- ** Trees
     -- | See <https://developer.github.com/v3/git/trees/>
@@ -146,11 +154,8 @@ module GitHub (
     --
     milestonesR,
     milestoneR,
-    createMilestone,
     createMilestoneR,
-    updateMilestone,
     updateMilestoneR,
-    deleteMilestone,
     deleteMilestoneR,
 
     -- * Organizations
@@ -172,6 +177,11 @@ module GitHub (
     membersOfWithR,
     isMemberOfR,
     orgInvitationsR,
+    -- ** Outside Collaborators
+    -- | See <https://developer.github.com/v3/orgs/outside_collaborators/>
+    --
+    -- Missing endpoints: All except /Outside Collaborator List/
+    outsideCollaboratorsR,
 
     -- ** Teams
     -- | See <https://developer.github.com/v3/orgs/teams/>
@@ -220,6 +230,7 @@ module GitHub (
     pullRequestCommentsR,
     pullRequestCommentR,
     createPullCommentR,
+    createPullCommentReplyR,
 
     -- ** Pull request reviews
     -- | See <https://developer.github.com/v3/pulls/reviews/>
@@ -231,14 +242,8 @@ module GitHub (
     -- * Submit a pull request review
     -- * Dismiss a pull request review
     pullRequestReviewsR,
-    pullRequestReviews,
-    pullRequestReviews',
     pullRequestReviewR,
-    pullRequestReview,
-    pullRequestReview',
     pullRequestReviewCommentsR,
-    pullRequestReviewCommentsIO,
-    pullRequestReviewCommentsIO',
 
     -- * Repositories
     -- | See <https://developer.github.com/v3/repos/>
@@ -261,6 +266,7 @@ module GitHub (
     -- ** Collaborators
     -- | See <https://developer.github.com/v3/repos/collaborators/>
     collaboratorsOnR,
+    collaboratorPermissionOnR,
     isCollaboratorOnR,
     addCollaboratorR,
 
@@ -283,6 +289,22 @@ module GitHub (
     commitR,
     diffR,
 
+    -- ** Contents
+    -- | See <https://developer.github.com/v3/repos/contents/>
+    contentsForR,
+    readmeForR,
+    archiveForR,
+    createFileR,
+    updateFileR,
+    deleteFileR,
+
+    -- ** Deploy Keys
+    -- | See <https://developer.github.com/v3/repos/keys/>
+    deployKeysForR,
+    deployKeyForR,
+    createRepoDeployKeyR,
+    deleteRepoDeployKeyR,
+
     -- ** Deployments
     -- | See <https://developer.github.com/v3/repos/deployments/#deployments>
     --
@@ -303,6 +325,12 @@ module GitHub (
     -- * Create a fork
     forksForR,
 
+    -- ** Statuses
+    -- | See <https://developer.github.com/v3/repos/statuses/>
+    createStatusR,
+    statusesForR,
+    statusForR,
+
     -- ** Webhooks
     -- | See <https://developer.github.com/v3/repos/hooks/>
     webhooksForR,
@@ -334,13 +362,10 @@ module GitHub (
 
     -- * Search
     -- | See <https://developer.github.com/v3/search/>
-    --
-    -- Missing endpoints:
-    --
-    -- * Search users
     searchReposR,
     searchCodeR,
     searchIssuesR,
+    searchUsersR,
 
     -- * Users
     -- | See <https://developer.github.com/v3/users/>
@@ -376,11 +401,13 @@ module GitHub (
     usersFollowingR,
     usersFollowedByR,
 
-    -- ** Statuses
-    -- | See <https://developer.github.com/v3/repos/statuses/>
-    createStatusR,
-    statusesForR,
-    statusForR,
+    -- ** Git SSH Keys
+    -- | See <https://developer.github.com/v3/users/keys/>
+    publicSSHKeysR,
+    publicSSHKeysForR,
+    publicSSHKeyR,
+    createUserPublicSSHKeyR,
+    deleteUserPublicSSHKeyR,
 
     -- ** Rate Limit
     -- | See <https://developer.github.com/v3/rate_limit/>
@@ -410,6 +437,7 @@ import GitHub.Endpoints.Issues.Labels
 import GitHub.Endpoints.Issues.Milestones
 import GitHub.Endpoints.Organizations
 import GitHub.Endpoints.Organizations.Members
+import GitHub.Endpoints.Organizations.OutsideCollaborators
 import GitHub.Endpoints.Organizations.Teams
 import GitHub.Endpoints.PullRequests
 import GitHub.Endpoints.PullRequests.Comments
@@ -419,6 +447,8 @@ import GitHub.Endpoints.Repos
 import GitHub.Endpoints.Repos.Collaborators
 import GitHub.Endpoints.Repos.Comments
 import GitHub.Endpoints.Repos.Commits
+import GitHub.Endpoints.Repos.Contents
+import GitHub.Endpoints.Repos.DeployKeys
 import GitHub.Endpoints.Repos.Deployments
 import GitHub.Endpoints.Repos.Forks
 import GitHub.Endpoints.Repos.Invitations
@@ -429,4 +459,5 @@ import GitHub.Endpoints.Search
 import GitHub.Endpoints.Users
 import GitHub.Endpoints.Users.Emails
 import GitHub.Endpoints.Users.Followers
+import GitHub.Endpoints.Users.PublicSSHKeys
 import GitHub.Request
