@@ -1,5 +1,4 @@
-{-# LANGUAGE DeriveDataTypeable #-}
-{-# LANGUAGE DeriveGeneric      #-}
+{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- License     :  BSD-3-Clause
@@ -11,14 +10,13 @@ module GitHub.Data.Name (
     untagName,
     ) where
 
-import Control.DeepSeq     (NFData (..))
-import Data.Aeson.Compat   (FromJSON (..), ToJSON (..))
-import Data.Binary.Orphans (Binary)
-import Data.Data           (Data, Typeable)
-import Data.Hashable       (Hashable)
-import Data.String         (IsString (..))
-import Data.Text           (Text)
-import GHC.Generics        (Generic)
+import Prelude ()
+import GitHub.Internal.Prelude
+
+#if MIN_VERSION_aeson(1,0,0)
+import Data.Aeson.Types
+       (FromJSONKey (..), ToJSONKey (..), fromJSONKeyCoerce, toJSONKeyText)
+#endif
 
 newtype Name entity = N Text
     deriving (Eq, Ord, Show, Generic, Typeable, Data)
@@ -44,3 +42,13 @@ instance ToJSON (Name entity) where
 
 instance IsString (Name entity) where
     fromString = N . fromString
+
+#if MIN_VERSION_aeson(1,0,0)
+-- | @since 0.15.0.0
+instance ToJSONKey (Name entity) where
+    toJSONKey = toJSONKeyText untagName
+
+-- | @since 0.15.0.0
+instance FromJSONKey (Name entity) where
+    fromJSONKey = fromJSONKeyCoerce
+#endif
